@@ -4,7 +4,6 @@ from collections.abc import Iterable
 from typing import TYPE_CHECKING, Any
 
 import numpy as np
-from packaging.version import Version
 
 from xarray.backends.common import (
     BACKEND_ENTRYPOINTS,
@@ -15,7 +14,6 @@ from xarray.backends.common import (
 )
 from xarray.backends.store import StoreBackendEntrypoint
 from xarray.core import indexing
-from xarray.core.pycompat import integer_types
 from xarray.core.utils import (
     Frozen,
     FrozenDict,
@@ -24,12 +22,13 @@ from xarray.core.utils import (
     is_remote_uri,
 )
 from xarray.core.variable import Variable
+from xarray.namedarray.pycompat import integer_types
 
 if TYPE_CHECKING:
     import os
-    from io import BufferedIOBase
 
     from xarray.core.dataset import Dataset
+    from xarray.core.types import ReadBuffer
 
 
 class PydapArrayWrapper(BackendArray):
@@ -123,11 +122,10 @@ class PydapDataStore(AbstractDataStore):
             "output_grid": output_grid or True,
             "timeout": timeout,
         }
-        if Version(pydap.lib.__version__) >= Version("3.3.0"):
-            if verify is not None:
-                kwargs.update({"verify": verify})
-            if user_charset is not None:
-                kwargs.update({"user_charset": user_charset})
+        if verify is not None:
+            kwargs.update({"verify": verify})
+        if user_charset is not None:
+            kwargs.update({"user_charset": user_charset})
         ds = pydap.client.open_url(**kwargs)
         return cls(ds)
 
@@ -168,13 +166,13 @@ class PydapBackendEntrypoint(BackendEntrypoint):
 
     def guess_can_open(
         self,
-        filename_or_obj: str | os.PathLike[Any] | BufferedIOBase | AbstractDataStore,
+        filename_or_obj: str | os.PathLike[Any] | ReadBuffer | AbstractDataStore,
     ) -> bool:
         return isinstance(filename_or_obj, str) and is_remote_uri(filename_or_obj)
 
-    def open_dataset(  # type: ignore[override]  # allow LSP violation, not supporting **kwargs
+    def open_dataset(
         self,
-        filename_or_obj: str | os.PathLike[Any] | BufferedIOBase | AbstractDataStore,
+        filename_or_obj: str | os.PathLike[Any] | ReadBuffer | AbstractDataStore,
         *,
         mask_and_scale=True,
         decode_times=True,
