@@ -1,11 +1,11 @@
-"""Functions for converting to and from xarray objects
-"""
+"""Functions for converting to and from xarray objects"""
 
 from collections import Counter
 
 import numpy as np
 
-from xarray.coding.times import CFDatetimeCoder, CFTimedeltaCoder
+from xarray.coders import CFDatetimeCoder
+from xarray.coding.times import CFTimedeltaCoder
 from xarray.conventions import decode_cf
 from xarray.core import duck_array_ops
 from xarray.core.dataarray import DataArray
