@@ -52,7 +52,6 @@ from unicodedata import normalize
 import numpy as np
 
 from xarray.core import duck_array_ops
-from xarray.core.computation import apply_ufunc
 from xarray.core.types import T_DataArray
 
 if TYPE_CHECKING:
@@ -127,6 +126,8 @@ def _apply_str_ufunc(
     if output_sizes is not None:
         dask_gufunc_kwargs["output_sizes"] = output_sizes
 
+    from xarray.computation.apply_ufunc import apply_ufunc
+
     return apply_ufunc(
         func,
         obj,
