@@ -1,4 +1,5 @@
 """Resampling for CFTimeIndex. Does not support non-integer freq."""
+
 # The mechanisms for resampling CFTimeIndex was copied and adapted from
 # the source code defined in pandas.core.resample
 #
@@ -45,12 +46,11 @@ import pandas as pd
 
 from xarray.coding.cftime_offsets import (
     BaseCFTimeOffset,
-    Day,
     MonthEnd,
     QuarterEnd,
     Tick,
     YearEnd,
-    cftime_range,
+    date_range,
     normalize_date,
     to_offset,
 )
@@ -58,7 +58,7 @@ from xarray.coding.cftimeindex import CFTimeIndex
 from xarray.core.types import SideOptions
 
 if typing.TYPE_CHECKING:
-    from xarray.core.types import CFTimeDatetime
+    from xarray.core.types import CFTimeDatetime, ResampleCompatible
 
 
 class CFTimeGrouper:
@@ -66,28 +66,25 @@ class CFTimeGrouper:
     single method, the only one required for resampling in xarray.  It cannot
     be used in a call to groupby like a pandas.Grouper object can."""
 
+    freq: BaseCFTimeOffset
+    closed: SideOptions
+    label: SideOptions
+    loffset: str | datetime.timedelta | BaseCFTimeOffset | None
+    origin: str | CFTimeDatetime
+    offset: datetime.timedelta | None
+
     def __init__(
         self,
-        freq: str | BaseCFTimeOffset,
+        freq: ResampleCompatible | BaseCFTimeOffset,
         closed: SideOptions | None = None,
         label: SideOptions | None = None,
-        base: int | None = None,
-        loffset: str | datetime.timedelta | BaseCFTimeOffset | None = None,
         origin: str | CFTimeDatetime = "start_day",
-        offset: str | datetime.timedelta | None = None,
+        offset: str | datetime.timedelta | BaseCFTimeOffset | None = None,
     ):
-        self.offset: datetime.timedelta | None
-        self.closed: SideOptions
-        self.label: SideOptions
-
-        if base is not None and offset is not None:
-            raise ValueError("base and offset cannot be provided at the same time")
-
         self.freq = to_offset(freq)
-        self.loffset = loffset
         self.origin = origin
 
-        if isinstance(self.freq, (MonthEnd, QuarterEnd, YearEnd)):
+        if isinstance(self.freq, MonthEnd | QuarterEnd | YearEnd):
             if closed is None:
                 self.closed = "right"
             else:
@@ -122,16 +119,13 @@ class CFTimeGrouper:
                 else:
                     self.label = label
 
-        if base is not None and isinstance(self.freq, Tick):
-            offset = type(self.freq)(n=base % self.freq.n).as_timedelta()
-
         if offset is not None:
             try:
                 self.offset = _convert_offset_to_timedelta(offset)
-            except (ValueError, AttributeError) as error:
+            except (ValueError, TypeError) as error:
                 raise ValueError(
                     f"offset must be a datetime.timedelta object or an offset string "
-                    f"that can be converted to a timedelta.  Got {offset} instead."
+                    f"that can be converted to a timedelta. Got {type(offset)} instead."
                 ) from error
         else:
             self.offset = None
@@ -149,24 +143,20 @@ class CFTimeGrouper:
         datetime_bins, labels = _get_time_bins(
             index, self.freq, self.closed, self.label, self.origin, self.offset
         )
-        if self.loffset is not None:
-            if isinstance(self.loffset, datetime.timedelta):
-                labels = labels + self.loffset
-            else:
-                labels = labels + to_offset(self.loffset)
-
         # check binner fits data
         if index[0] < datetime_bins[0]:
             raise ValueError("Value falls before first bin")
         if index[-1] > datetime_bins[-1]:
             raise ValueError("Value falls after last bin")
 
-        integer_bins = np.searchsorted(index, datetime_bins, side=self.closed)[:-1]
-        first_items = pd.Series(integer_bins, labels)
+        integer_bins = np.searchsorted(index, datetime_bins, side=self.closed)
+        counts = np.diff(integer_bins)
+        codes = np.repeat(np.arange(len(labels)), counts)
+        first_items = pd.Series(integer_bins[:-1], labels, copy=False)
 
         # Mask duplicate values with NaNs, preserving the last values
         non_duplicate = ~first_items.duplicated("last")
-        return first_items.where(non_duplicate)
+        return first_items.where(non_duplicate), codes
 
 
 def _get_time_bins(
@@ -229,8 +219,8 @@ def _get_time_bins(
     first, last = _get_range_edges(
         index.min(), index.max(), freq, closed=closed, origin=origin, offset=offset
     )
-    datetime_bins = labels = cftime_range(
-        freq=freq, start=first, end=last, name=index.name
+    datetime_bins = labels = date_range(
+        freq=freq, start=first, end=last, name=index.name, use_cftime=True
     )
 
     datetime_bins, labels = _adjust_bin_edges(
@@ -246,15 +236,14 @@ def _get_time_bins(
 
 
 def _adjust_bin_edges(
-    datetime_bins: np.ndarray,
+    datetime_bins: CFTimeIndex,
     freq: BaseCFTimeOffset,
     closed: SideOptions,
     index: CFTimeIndex,
-    labels: np.ndarray,
-):
+    labels: CFTimeIndex,
+) -> tuple[CFTimeIndex, CFTimeIndex]:
     """This is required for determining the bin edges resampling with
-    daily frequencies greater than one day, month end, and year end
-    frequencies.
+    month end, quarter end, and year end frequencies.
 
     Consider the following example.  Let's say you want to downsample the
     time series with the following coordinates to month end frequency:
@@ -282,14 +271,8 @@ def _adjust_bin_edges(
     The labels are still:
 
     CFTimeIndex([2000-01-31 00:00:00, 2000-02-29 00:00:00], dtype='object')
-
-    This is also required for daily frequencies longer than one day and
-    year-end frequencies.
     """
-    is_super_daily = isinstance(freq, (MonthEnd, QuarterEnd, YearEnd)) or (
-        isinstance(freq, Day) and freq.n > 1
-    )
-    if is_super_daily:
+    if isinstance(freq, MonthEnd | QuarterEnd | YearEnd):
         if closed == "right":
             datetime_bins = datetime_bins + datetime.timedelta(days=1, microseconds=-1)
         if datetime_bins[-2] > index.max():
@@ -502,10 +485,11 @@ def _convert_offset_to_timedelta(
 ) -> datetime.timedelta:
     if isinstance(offset, datetime.timedelta):
         return offset
-    elif isinstance(offset, (str, Tick)):
-        return to_offset(offset).as_timedelta()
-    else:
-        raise ValueError
+    if isinstance(offset, str | Tick):
+        timedelta_cftime_offset = to_offset(offset)
+        if isinstance(timedelta_cftime_offset, Tick):
+            return timedelta_cftime_offset.as_timedelta()
+    raise TypeError(f"Expected timedelta, str or Tick, got {type(offset)}")
 
 
 def _ceil_via_cftimeindex(date: CFTimeDatetime, freq: str | BaseCFTimeOffset):
