@@ -3,10 +3,9 @@ from __future__ import annotations
 import functools
 import inspect
 import warnings
-from collections.abc import Hashable, Iterable
-from typing import TYPE_CHECKING, Any, Callable, TypeVar, overload
+from collections.abc import Callable, Hashable, Iterable
+from typing import TYPE_CHECKING, Any, TypeVar, overload
 
-from xarray.core.alignment import broadcast
 from xarray.plot import dataarray_plot
 from xarray.plot.facetgrid import _easy_facetgrid
 from xarray.plot.utils import (
@@ -16,6 +15,7 @@ from xarray.plot.utils import (
     _process_cmap_cbar_kwargs,
     get_axis,
 )
+from xarray.structure.alignment import broadcast
 
 if TYPE_CHECKING:
     from matplotlib.axes import Axes
@@ -103,7 +103,7 @@ def _dsplot(plotfunc):
         be either ``'viridis'`` (if the function infers a sequential
         dataset) or ``'RdBu_r'`` (if the function infers a diverging
         dataset).
-        See :doc:`Choosing Colormaps in Matplotlib <matplotlib:tutorials/colors/colormaps>`
+        See :doc:`Choosing Colormaps in Matplotlib <matplotlib:users/explain/colors/colormaps>`
         for more information.
 
         If *seaborn* is installed, ``cmap`` may also be a
@@ -321,7 +321,7 @@ def _dsplot(plotfunc):
 
 
 @overload
-def quiver(
+def quiver(  # type: ignore[misc,unused-ignore]  # None is hashable :(
     ds: Dataset,
     *args: Any,
     x: Hashable | None = None,
@@ -354,8 +354,7 @@ def quiver(
     extend: ExtendOptions = None,
     cmap: str | Colormap | None = None,
     **kwargs: Any,
-) -> Quiver:
-    ...
+) -> Quiver: ...
 
 
 @overload
@@ -392,8 +391,7 @@ def quiver(
     extend: ExtendOptions = None,
     cmap: str | Colormap | None = None,
     **kwargs: Any,
-) -> FacetGrid[Dataset]:
-    ...
+) -> FacetGrid[Dataset]: ...
 
 
 @overload
@@ -430,8 +428,7 @@ def quiver(
     extend: ExtendOptions = None,
     cmap: str | Colormap | None = None,
     **kwargs: Any,
-) -> FacetGrid[Dataset]:
-    ...
+) -> FacetGrid[Dataset]: ...
 
 
 @_dsplot
@@ -475,7 +472,7 @@ def quiver(
 
 
 @overload
-def streamplot(
+def streamplot(  # type: ignore[misc,unused-ignore]  # None is hashable :(
     ds: Dataset,
     *args: Any,
     x: Hashable | None = None,
@@ -508,8 +505,7 @@ def streamplot(
     extend: ExtendOptions = None,
     cmap: str | Colormap | None = None,
     **kwargs: Any,
-) -> LineCollection:
-    ...
+) -> LineCollection: ...
 
 
 @overload
@@ -546,8 +542,7 @@ def streamplot(
     extend: ExtendOptions = None,
     cmap: str | Colormap | None = None,
     **kwargs: Any,
-) -> FacetGrid[Dataset]:
-    ...
+) -> FacetGrid[Dataset]: ...
 
 
 @overload
@@ -584,8 +579,7 @@ def streamplot(
     extend: ExtendOptions = None,
     cmap: str | Colormap | None = None,
     **kwargs: Any,
-) -> FacetGrid[Dataset]:
-    ...
+) -> FacetGrid[Dataset]: ...
 
 
 @_dsplot
@@ -632,7 +626,6 @@ def streamplot(
         du = du.transpose(ydim, xdim)
         dv = dv.transpose(ydim, xdim)
 
-    args = [dx.values, dy.values, du.values, dv.values]
     hue = kwargs.pop("hue")
     cmap_params = kwargs.pop("cmap_params")
 
@@ -646,7 +639,9 @@ def streamplot(
             )
 
     kwargs.pop("hue_style")
-    hdl = ax.streamplot(*args, **kwargs, **cmap_params)
+    hdl = ax.streamplot(
+        dx.values, dy.values, du.values, dv.values, **kwargs, **cmap_params
+    )
 
     # Return .lines so colorbar creation works properly
     return hdl.lines
@@ -657,7 +652,7 @@ F = TypeVar("F", bound=Callable)
 
 def _update_doc_to_dataset(dataarray_plotfunc: Callable) -> Callable[[F], F]:
     """
-    Add a common docstring by re-using the DataArray one.
+    Add a common docstring by reusing the DataArray one.
 
     TODO: Reduce code duplication.
 
@@ -702,7 +697,7 @@ def _update_doc_to_dataset(dataarray_plotfunc: Callable) -> Callable[[F], F]:
         dataset_plotfunc.__doc__ = ds_doc
         return dataset_plotfunc
 
-    return wrapper
+    return wrapper  # type: ignore[return-value]
 
 
 def _normalize_args(
@@ -726,29 +721,34 @@ def _temp_dataarray(ds: Dataset, y: Hashable, locals_: dict[str, Any]) -> DataAr
     """Create a temporary datarray with extra coords."""
     from xarray.core.dataarray import DataArray
 
-    # Base coords:
-    coords = dict(ds.coords)
+    coords = dict(ds[y].coords)
+    dims = set(ds[y].dims)
 
     # Add extra coords to the DataArray from valid kwargs, if using all
-    # kwargs there is a risk that we add unneccessary dataarrays as
+    # kwargs there is a risk that we add unnecessary dataarrays as
     # coords straining RAM further for example:
     # ds.both and extend="both" would add ds.both to the coords:
     valid_coord_kwargs = {"x", "z", "markersize", "hue", "row", "col", "u", "v"}
     coord_kwargs = locals_.keys() & valid_coord_kwargs
     for k in coord_kwargs:
         key = locals_[k]
-        if ds.data_vars.get(key) is not None:
-            coords[key] = ds[key]
+        darray = ds.get(key)
+        if darray is not None:
+            coords[key] = darray
+            dims.update(darray.dims)
+
+    # Trim dataset from unnecessary dims:
+    ds_trimmed = ds.drop_dims(ds.sizes.keys() - dims)  # TODO: Use ds.dims in the future
 
     # The dataarray has to include all the dims. Broadcast to that shape
     # and add the additional coords:
-    _y = ds[y].broadcast_like(ds)
+    _y = ds[y].broadcast_like(ds_trimmed)
 
     return DataArray(_y, coords=coords)
 
 
 @overload
-def scatter(
+def scatter(  # type: ignore[misc,unused-ignore]  # None is hashable :(
     ds: Dataset,
     *args: Any,
     x: Hashable | None = None,
@@ -785,8 +785,7 @@ def scatter(
     extend: ExtendOptions = None,
     levels: ArrayLike | None = None,
     **kwargs: Any,
-) -> PathCollection:
-    ...
+) -> PathCollection: ...
 
 
 @overload
@@ -827,8 +826,7 @@ def scatter(
     extend: ExtendOptions = None,
     levels: ArrayLike | None = None,
     **kwargs: Any,
-) -> FacetGrid[DataArray]:
-    ...
+) -> FacetGrid[DataArray]: ...
 
 
 @overload
@@ -869,8 +867,7 @@ def scatter(
     extend: ExtendOptions = None,
     levels: ArrayLike | None = None,
     **kwargs: Any,
-) -> FacetGrid[DataArray]:
-    ...
+) -> FacetGrid[DataArray]: ...
 
 
 @_update_doc_to_dataset(dataarray_plot.scatter)
