@@ -6,6 +6,8 @@ import pytest
 
 import xarray as xr
 from xarray.tests import (
+    _CFTIME_CALENDARS,
+    _all_cftime_date_types,
     assert_allclose,
     assert_array_equal,
     assert_chunks_equal,
@@ -390,15 +392,6 @@ class TestTimedeltaAccessor:
         assert_equal(actual.compute(), expected.compute())
 
 
-_CFTIME_CALENDARS = [
-    "365_day",
-    "360_day",
-    "julian",
-    "all_leap",
-    "366_day",
-    "gregorian",
-    "proleptic_gregorian",
-]
 _NT = 100
 
 
@@ -407,6 +400,13 @@ def calendar(request):
     return request.param
 
 
+@pytest.fixture()
+def cftime_date_type(calendar):
+    if calendar == "standard":
+        calendar = "proleptic_gregorian"
+    return _all_cftime_date_types()[calendar]
+
+
 @pytest.fixture()
 def times(calendar):
     import cftime
@@ -519,7 +519,9 @@ def test_cftime_strftime_access(data) -> None:
     date_format = "%Y%m%d%H"
     result = data.time.dt.strftime(date_format)
     datetime_array = xr.DataArray(
-        xr.coding.cftimeindex.CFTimeIndex(data.time.values).to_datetimeindex(),
+        xr.coding.cftimeindex.CFTimeIndex(data.time.values).to_datetimeindex(
+            time_unit="ns"
+        ),
         name="stftime",
         coords=data.time.coords,
         dims=data.time.dims,
@@ -571,13 +573,6 @@ def test_dask_field_access(times_3d, data, field) -> None:
     assert_equal(result.compute(), expected)
 
 
-@pytest.fixture()
-def cftime_date_type(calendar):
-    from xarray.tests.test_coding_times import _all_cftime_date_types
-
-    return _all_cftime_date_types()[calendar]
-
-
 @requires_cftime
 def test_seasons(cftime_date_type) -> None:
     dates = xr.DataArray(
