@@ -352,7 +352,7 @@ class TestPandasMultiIndex:
         # default level names
         pd_idx = pd.MultiIndex.from_arrays([foo_data, bar_data])
         index = PandasMultiIndex(pd_idx, "x")
-        assert index.index.names == ("x_level_0", "x_level_1")
+        assert list(index.index.names) == ["x_level_0", "x_level_1"]
 
     def test_from_variables(self) -> None:
         v_level1 = xr.Variable(
@@ -370,7 +370,7 @@ class TestPandasMultiIndex:
         assert index.dim == "x"
         assert index.index.equals(expected_idx)
         assert index.index.name == "x"
-        assert index.index.names == ["level1", "level2"]
+        assert list(index.index.names) == ["level1", "level2"]
 
         var = xr.Variable(("x", "y"), [[1, 2, 3], [4, 5, 6]])
         with pytest.raises(
@@ -410,12 +410,15 @@ class TestPandasMultiIndex:
             "y": xr.Variable("y", pd.Index([1, 3, 2])),
         }
 
-        index = PandasMultiIndex.stack(prod_vars, "z")
+        index_xr = PandasMultiIndex.stack(prod_vars, "z")
 
-        assert index.dim == "z"
-        assert index.index.names == ["x", "y"]
+        assert index_xr.dim == "z"
+        index_pd = index_xr.index
+        assert isinstance(index_pd, pd.MultiIndex)
+        # TODO: change to tuple when pandas 3 is minimum
+        assert list(index_pd.names) == ["x", "y"]
         np.testing.assert_array_equal(
-            index.index.codes, [[0, 0, 0, 1, 1, 1], [0, 1, 2, 0, 1, 2]]
+            index_pd.codes, [[0, 0, 0, 1, 1, 1], [0, 1, 2, 0, 1, 2]]
         )
 
         with pytest.raises(
@@ -432,13 +435,15 @@ class TestPandasMultiIndex:
             "y": xr.Variable("y", pd.Index([1, 1, 2])),
         }
 
-        index = PandasMultiIndex.stack(prod_vars, "z")
+        index_xr = PandasMultiIndex.stack(prod_vars, "z")
+        index_pd = index_xr.index
+        assert isinstance(index_pd, pd.MultiIndex)
 
         np.testing.assert_array_equal(
-            index.index.codes, [[0, 0, 0, 1, 1, 1], [0, 0, 1, 0, 0, 1]]
+            index_pd.codes, [[0, 0, 0, 1, 1, 1], [0, 0, 1, 0, 0, 1]]
         )
-        np.testing.assert_array_equal(index.index.levels[0], ["b", "a"])
-        np.testing.assert_array_equal(index.index.levels[1], [1, 2])
+        np.testing.assert_array_equal(index_pd.levels[0], ["b", "a"])
+        np.testing.assert_array_equal(index_pd.levels[1], [1, 2])
 
     def test_unstack(self) -> None:
         pd_midx = pd.MultiIndex.from_product(
@@ -531,12 +536,12 @@ class TestPandasMultiIndex:
         assert new_index is index
 
         new_index = index.rename({"two": "three"}, {})
-        assert new_index.index.names == ["one", "three"]
+        assert list(new_index.index.names) == ["one", "three"]
         assert new_index.dim == "x"
         assert new_index.level_coords_dtype == {"one": "<U1", "three": np.int32}
 
         new_index = index.rename({}, {"x": "y"})
-        assert new_index.index.names == ["one", "two"]
+        assert list(new_index.index.names) == ["one", "two"]
         assert new_index.dim == "y"
         assert new_index.level_coords_dtype == level_coords_dtype
 
@@ -599,10 +604,7 @@ class TestIndexes:
 
         _, variables = indexes_and_vars
 
-        if isinstance(x_idx, Index):
-            index_type = Index
-        else:
-            index_type = pd.Index
+        index_type = Index if isinstance(x_idx, Index) else pd.Index
 
         return Indexes(indexes, variables, index_type=index_type)
 
@@ -665,20 +667,22 @@ class TestIndexes:
     def test_to_pandas_indexes(self, indexes) -> None:
         pd_indexes = indexes.to_pandas_indexes()
         assert isinstance(pd_indexes, Indexes)
-        assert all([isinstance(idx, pd.Index) for idx in pd_indexes.values()])
+        assert all(isinstance(idx, pd.Index) for idx in pd_indexes.values())
         assert indexes.variables == pd_indexes.variables
 
     def test_copy_indexes(self, indexes) -> None:
         copied, index_vars = indexes.copy_indexes()
 
         assert copied.keys() == indexes.keys()
-        for new, original in zip(copied.values(), indexes.values()):
+        for new, original in zip(copied.values(), indexes.values(), strict=True):
             assert new.equals(original)
         # check unique index objects preserved
         assert copied["z"] is copied["one"] is copied["two"]
 
         assert index_vars.keys() == indexes.variables.keys()
-        for new, original in zip(index_vars.values(), indexes.variables.values()):
+        for new, original in zip(
+            index_vars.values(), indexes.variables.values(), strict=True
+        ):
             assert_identical(new, original)
 
 
