@@ -4,8 +4,9 @@ import numpy as np
 import pytest
 
 import xarray as xr
-from xarray.core import dtypes, merge
-from xarray.core.merge import MergeError
+from xarray.core import dtypes
+from xarray.structure import merge
+from xarray.structure.merge import MergeError
 from xarray.testing import assert_equal, assert_identical
 from xarray.tests.test_dataset import create_test_data
 
@@ -37,7 +38,7 @@ class TestMergeFunction:
         assert_identical(actual, expected)
 
     def test_merge_datasets(self):
-        data = create_test_data(add_attrs=False)
+        data = create_test_data(add_attrs=False, use_extension_array=True)
 
         actual = xr.merge([data[["var1"]], data[["var2"]]])
         expected = data[["var1", "var2"]]
